@@ -1,4 +1,4 @@
 __version__ = '0.0.1'
 __all__ = ['consistency', 'feature_operations', 'parser',
            'recognition', 'time_series', 'utils', 'visualisation',
-           'config']
\ No newline at end of file
+           'config', 'logs']
